artist

package
v0.0.0-...-b1298dc Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Sep 10, 2023 License: MIT Imports: 3 Imported by: 0

Documentation

Index

Constants

const (
	// Label holds the string label denoting the artist type in the database.
	Label = "artist"
	// FieldID holds the string denoting the id field in the database.
	FieldID = "id"
	// FieldName holds the string denoting the name field in the database.
	FieldName = "name"
	// EdgeSongs holds the string denoting the songs edge name in mutations.
	EdgeSongs = "songs"
	// Table holds the table name of the artist in the database.
	Table = "artists"
	// SongsTable is the table that holds the songs relation/edge.
	SongsTable = "songs"
	// SongsInverseTable is the table name for the Song entity.
	// It exists in this package in order to avoid circular dependency with the "song" package.
	SongsInverseTable = "songs"
	// SongsColumn is the table column denoting the songs relation/edge.
	SongsColumn = "artist_id"
)

Variables

var Columns = []string{
	FieldID,
	FieldName,
}

Columns holds all SQL columns for artist fields.

Functions

func And

func And(predicates ...predicate.Artist) predicate.Artist

And groups predicates with the AND operator between them.

func HasSongs

func HasSongs() predicate.Artist

HasSongs applies the HasEdge predicate on the "songs" edge.

func HasSongsWith

func HasSongsWith(preds ...predicate.Song) predicate.Artist

HasSongsWith applies the HasEdge predicate on the "songs" edge with a given conditions (other predicates).

func ID

func ID(id int) predicate.Artist

ID filters vertices based on their ID field.

func IDEQ

func IDEQ(id int) predicate.Artist

IDEQ applies the EQ predicate on the ID field.

func IDGT

func IDGT(id int) predicate.Artist

IDGT applies the GT predicate on the ID field.

func IDGTE

func IDGTE(id int) predicate.Artist

IDGTE applies the GTE predicate on the ID field.

func IDIn

func IDIn(ids ...int) predicate.Artist

IDIn applies the In predicate on the ID field.

func IDLT

func IDLT(id int) predicate.Artist

IDLT applies the LT predicate on the ID field.

func IDLTE

func IDLTE(id int) predicate.Artist

IDLTE applies the LTE predicate on the ID field.

func IDNEQ

func IDNEQ(id int) predicate.Artist

IDNEQ applies the NEQ predicate on the ID field.

func IDNotIn

func IDNotIn(ids ...int) predicate.Artist

IDNotIn applies the NotIn predicate on the ID field.

func Name

func Name(v string) predicate.Artist

Name applies equality check predicate on the "name" field. It's identical to NameEQ.

func NameContains

func NameContains(v string) predicate.Artist

NameContains applies the Contains predicate on the "name" field.

func NameContainsFold

func NameContainsFold(v string) predicate.Artist

NameContainsFold applies the ContainsFold predicate on the "name" field.

func NameEQ

func NameEQ(v string) predicate.Artist

NameEQ applies the EQ predicate on the "name" field.

func NameEqualFold

func NameEqualFold(v string) predicate.Artist

NameEqualFold applies the EqualFold predicate on the "name" field.

func NameGT

func NameGT(v string) predicate.Artist

NameGT applies the GT predicate on the "name" field.

func NameGTE

func NameGTE(v string) predicate.Artist

NameGTE applies the GTE predicate on the "name" field.

func NameHasPrefix

func NameHasPrefix(v string) predicate.Artist

NameHasPrefix applies the HasPrefix predicate on the "name" field.

func NameHasSuffix

func NameHasSuffix(v string) predicate.Artist

NameHasSuffix applies the HasSuffix predicate on the "name" field.

func NameIn

func NameIn(vs ...string) predicate.Artist

NameIn applies the In predicate on the "name" field.

func NameLT

func NameLT(v string) predicate.Artist

NameLT applies the LT predicate on the "name" field.

func NameLTE

func NameLTE(v string) predicate.Artist

NameLTE applies the LTE predicate on the "name" field.

func NameNEQ

func NameNEQ(v string) predicate.Artist

NameNEQ applies the NEQ predicate on the "name" field.

func NameNotIn

func NameNotIn(vs ...string) predicate.Artist

NameNotIn applies the NotIn predicate on the "name" field.

func Not

Not applies the not operator on the given predicate.

func Or

func Or(predicates ...predicate.Artist) predicate.Artist

Or groups predicates with the OR operator between them.

func ValidColumn

func ValidColumn(column string) bool

ValidColumn reports if the column name is valid (part of the table columns).

Types

type OrderOption

type OrderOption func(*sql.Selector)

OrderOption defines the ordering options for the Artist queries.

func ByID

func ByID(opts ...sql.OrderTermOption) OrderOption

ByID orders the results by the id field.

func ByName

func ByName(opts ...sql.OrderTermOption) OrderOption

ByName orders the results by the name field.

func BySongs

func BySongs(term sql.OrderTerm, terms ...sql.OrderTerm) OrderOption

BySongs orders the results by songs terms.

func BySongsCount

func BySongsCount(opts ...sql.OrderTermOption) OrderOption

BySongsCount orders the results by songs count.

Jump to