schema

package
v0.0.0-...-b1298dc Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Sep 10, 2023 License: MIT Imports: 5 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

This section is empty.

Types

type Artist

type Artist struct {
	ent.Schema
}

Artist holds the schema definition for the Artist entity.

func (Artist) Annotations

func (Artist) Annotations() []schema.Annotation

func (Artist) Edges

func (Artist) Edges() []ent.Edge

Edges of the Artist.

func (Artist) Fields

func (Artist) Fields() []ent.Field

Fields of the Artist.

type Song

type Song struct {
	ent.Schema
}

Song holds the schema definition for the Song entity.

func (Song) Annotations

func (Song) Annotations() []schema.Annotation

func (Song) Edges

func (Song) Edges() []ent.Edge

Edges of the Song.

func (Song) Fields

func (Song) Fields() []ent.Field

Fields of the Song.

Jump to