song

package
v0.0.0-...-b1298dc Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Sep 10, 2023 License: MIT Imports: 3 Imported by: 0

Documentation

Index

Constants

const (
	// Label holds the string label denoting the song type in the database.
	Label = "song"
	// FieldID holds the string denoting the id field in the database.
	FieldID = "id"
	// FieldTitle holds the string denoting the title field in the database.
	FieldTitle = "title"
	// FieldReleasedYear holds the string denoting the released_year field in the database.
	FieldReleasedYear = "released_year"
	// FieldArtistID holds the string denoting the artist_id field in the database.
	FieldArtistID = "artist_id"
	// EdgeArtist holds the string denoting the artist edge name in mutations.
	EdgeArtist = "artist"
	// Table holds the table name of the song in the database.
	Table = "songs"
	// ArtistTable is the table that holds the artist relation/edge.
	ArtistTable = "songs"
	// ArtistInverseTable is the table name for the Artist entity.
	// It exists in this package in order to avoid circular dependency with the "artist" package.
	ArtistInverseTable = "artists"
	// ArtistColumn is the table column denoting the artist relation/edge.
	ArtistColumn = "artist_id"
)

Variables

Columns holds all SQL columns for song fields.

Functions

func And

func And(predicates ...predicate.Song) predicate.Song

And groups predicates with the AND operator between them.

func ArtistID

func ArtistID(v int) predicate.Song

ArtistID applies equality check predicate on the "artist_id" field. It's identical to ArtistIDEQ.

func ArtistIDEQ

func ArtistIDEQ(v int) predicate.Song

ArtistIDEQ applies the EQ predicate on the "artist_id" field.

func ArtistIDIn

func ArtistIDIn(vs ...int) predicate.Song

ArtistIDIn applies the In predicate on the "artist_id" field.

func ArtistIDNEQ

func ArtistIDNEQ(v int) predicate.Song

ArtistIDNEQ applies the NEQ predicate on the "artist_id" field.

func ArtistIDNotIn

func ArtistIDNotIn(vs ...int) predicate.Song

ArtistIDNotIn applies the NotIn predicate on the "artist_id" field.

func HasArtist

func HasArtist() predicate.Song

HasArtist applies the HasEdge predicate on the "artist" edge.

func HasArtistWith

func HasArtistWith(preds ...predicate.Artist) predicate.Song

HasArtistWith applies the HasEdge predicate on the "artist" edge with a given conditions (other predicates).

func ID

func ID(id int) predicate.Song

ID filters vertices based on their ID field.

func IDEQ

func IDEQ(id int) predicate.Song

IDEQ applies the EQ predicate on the ID field.

func IDGT

func IDGT(id int) predicate.Song

IDGT applies the GT predicate on the ID field.

func IDGTE

func IDGTE(id int) predicate.Song

IDGTE applies the GTE predicate on the ID field.

func IDIn

func IDIn(ids ...int) predicate.Song

IDIn applies the In predicate on the ID field.

func IDLT

func IDLT(id int) predicate.Song

IDLT applies the LT predicate on the ID field.

func IDLTE

func IDLTE(id int) predicate.Song

IDLTE applies the LTE predicate on the ID field.

func IDNEQ

func IDNEQ(id int) predicate.Song

IDNEQ applies the NEQ predicate on the ID field.

func IDNotIn

func IDNotIn(ids ...int) predicate.Song

IDNotIn applies the NotIn predicate on the ID field.

func Not

Not applies the not operator on the given predicate.

func Or

func Or(predicates ...predicate.Song) predicate.Song

Or groups predicates with the OR operator between them.

func ReleasedYear

func ReleasedYear(v int) predicate.Song

ReleasedYear applies equality check predicate on the "released_year" field. It's identical to ReleasedYearEQ.

func ReleasedYearEQ

func ReleasedYearEQ(v int) predicate.Song

ReleasedYearEQ applies the EQ predicate on the "released_year" field.

func ReleasedYearGT

func ReleasedYearGT(v int) predicate.Song

ReleasedYearGT applies the GT predicate on the "released_year" field.

func ReleasedYearGTE

func ReleasedYearGTE(v int) predicate.Song

ReleasedYearGTE applies the GTE predicate on the "released_year" field.

func ReleasedYearIn

func ReleasedYearIn(vs ...int) predicate.Song

ReleasedYearIn applies the In predicate on the "released_year" field.

func ReleasedYearLT

func ReleasedYearLT(v int) predicate.Song

ReleasedYearLT applies the LT predicate on the "released_year" field.

func ReleasedYearLTE

func ReleasedYearLTE(v int) predicate.Song

ReleasedYearLTE applies the LTE predicate on the "released_year" field.

func ReleasedYearNEQ

func ReleasedYearNEQ(v int) predicate.Song

ReleasedYearNEQ applies the NEQ predicate on the "released_year" field.

func ReleasedYearNotIn

func ReleasedYearNotIn(vs ...int) predicate.Song

ReleasedYearNotIn applies the NotIn predicate on the "released_year" field.

func Title

func Title(v string) predicate.Song

Title applies equality check predicate on the "title" field. It's identical to TitleEQ.

func TitleContains

func TitleContains(v string) predicate.Song

TitleContains applies the Contains predicate on the "title" field.

func TitleContainsFold

func TitleContainsFold(v string) predicate.Song

TitleContainsFold applies the ContainsFold predicate on the "title" field.

func TitleEQ

func TitleEQ(v string) predicate.Song

TitleEQ applies the EQ predicate on the "title" field.

func TitleEqualFold

func TitleEqualFold(v string) predicate.Song

TitleEqualFold applies the EqualFold predicate on the "title" field.

func TitleGT

func TitleGT(v string) predicate.Song

TitleGT applies the GT predicate on the "title" field.

func TitleGTE

func TitleGTE(v string) predicate.Song

TitleGTE applies the GTE predicate on the "title" field.

func TitleHasPrefix

func TitleHasPrefix(v string) predicate.Song

TitleHasPrefix applies the HasPrefix predicate on the "title" field.

func TitleHasSuffix

func TitleHasSuffix(v string) predicate.Song

TitleHasSuffix applies the HasSuffix predicate on the "title" field.

func TitleIn

func TitleIn(vs ...string) predicate.Song

TitleIn applies the In predicate on the "title" field.

func TitleLT

func TitleLT(v string) predicate.Song

TitleLT applies the LT predicate on the "title" field.

func TitleLTE

func TitleLTE(v string) predicate.Song

TitleLTE applies the LTE predicate on the "title" field.

func TitleNEQ

func TitleNEQ(v string) predicate.Song

TitleNEQ applies the NEQ predicate on the "title" field.

func TitleNotIn

func TitleNotIn(vs ...string) predicate.Song

TitleNotIn applies the NotIn predicate on the "title" field.

func ValidColumn

func ValidColumn(column string) bool

ValidColumn reports if the column name is valid (part of the table columns).

Types

type OrderOption

type OrderOption func(*sql.Selector)

OrderOption defines the ordering options for the Song queries.

func ByArtistField

func ByArtistField(field string, opts ...sql.OrderTermOption) OrderOption

ByArtistField orders the results by artist field.

func ByArtistID

func ByArtistID(opts ...sql.OrderTermOption) OrderOption

ByArtistID orders the results by the artist_id field.

func ByID

func ByID(opts ...sql.OrderTermOption) OrderOption

ByID orders the results by the id field.

func ByReleasedYear

func ByReleasedYear(opts ...sql.OrderTermOption) OrderOption

ByReleasedYear orders the results by the released_year field.

func ByTitle

func ByTitle(opts ...sql.OrderTermOption) OrderOption

ByTitle orders the results by the title field.

Jump to