Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type Artist ¶
Artist holds the schema definition for the Artist entity.
func (Artist) Annotations ¶
func (Artist) Annotations() []schema.Annotation
type Song ¶
Song holds the schema definition for the Song entity.
func (Song) Annotations ¶
func (Song) Annotations() []schema.Annotation
Click to show internal directories.
Click to hide internal directories.