Documentation
¶
Index ¶
- Constants
- Variables
- func And(predicates ...predicate.Song) predicate.Song
- func ArtistID(v int) predicate.Song
- func ArtistIDEQ(v int) predicate.Song
- func ArtistIDIn(vs ...int) predicate.Song
- func ArtistIDNEQ(v int) predicate.Song
- func ArtistIDNotIn(vs ...int) predicate.Song
- func HasArtist() predicate.Song
- func HasArtistWith(preds ...predicate.Artist) predicate.Song
- func ID(id int) predicate.Song
- func IDEQ(id int) predicate.Song
- func IDGT(id int) predicate.Song
- func IDGTE(id int) predicate.Song
- func IDIn(ids ...int) predicate.Song
- func IDLT(id int) predicate.Song
- func IDLTE(id int) predicate.Song
- func IDNEQ(id int) predicate.Song
- func IDNotIn(ids ...int) predicate.Song
- func Not(p predicate.Song) predicate.Song
- func Or(predicates ...predicate.Song) predicate.Song
- func ReleasedYear(v int) predicate.Song
- func ReleasedYearEQ(v int) predicate.Song
- func ReleasedYearGT(v int) predicate.Song
- func ReleasedYearGTE(v int) predicate.Song
- func ReleasedYearIn(vs ...int) predicate.Song
- func ReleasedYearLT(v int) predicate.Song
- func ReleasedYearLTE(v int) predicate.Song
- func ReleasedYearNEQ(v int) predicate.Song
- func ReleasedYearNotIn(vs ...int) predicate.Song
- func Title(v string) predicate.Song
- func TitleContains(v string) predicate.Song
- func TitleContainsFold(v string) predicate.Song
- func TitleEQ(v string) predicate.Song
- func TitleEqualFold(v string) predicate.Song
- func TitleGT(v string) predicate.Song
- func TitleGTE(v string) predicate.Song
- func TitleHasPrefix(v string) predicate.Song
- func TitleHasSuffix(v string) predicate.Song
- func TitleIn(vs ...string) predicate.Song
- func TitleLT(v string) predicate.Song
- func TitleLTE(v string) predicate.Song
- func TitleNEQ(v string) predicate.Song
- func TitleNotIn(vs ...string) predicate.Song
- func ValidColumn(column string) bool
- type OrderOption
Constants ¶
const ( // Label holds the string label denoting the song type in the database. Label = "song" // FieldID holds the string denoting the id field in the database. FieldID = "id" // FieldTitle holds the string denoting the title field in the database. FieldTitle = "title" // FieldReleasedYear holds the string denoting the released_year field in the database. FieldReleasedYear = "released_year" // FieldArtistID holds the string denoting the artist_id field in the database. FieldArtistID = "artist_id" // EdgeArtist holds the string denoting the artist edge name in mutations. EdgeArtist = "artist" // Table holds the table name of the song in the database. Table = "songs" // ArtistTable is the table that holds the artist relation/edge. ArtistTable = "songs" // ArtistInverseTable is the table name for the Artist entity. // It exists in this package in order to avoid circular dependency with the "artist" package. ArtistInverseTable = "artists" // ArtistColumn is the table column denoting the artist relation/edge. ArtistColumn = "artist_id" )
Variables ¶
var Columns = []string{ FieldID, FieldTitle, FieldReleasedYear, FieldArtistID, }
Columns holds all SQL columns for song fields.
Functions ¶
func ArtistID ¶
ArtistID applies equality check predicate on the "artist_id" field. It's identical to ArtistIDEQ.
func ArtistIDEQ ¶
ArtistIDEQ applies the EQ predicate on the "artist_id" field.
func ArtistIDIn ¶
ArtistIDIn applies the In predicate on the "artist_id" field.
func ArtistIDNEQ ¶
ArtistIDNEQ applies the NEQ predicate on the "artist_id" field.
func ArtistIDNotIn ¶
ArtistIDNotIn applies the NotIn predicate on the "artist_id" field.
func HasArtistWith ¶
HasArtistWith applies the HasEdge predicate on the "artist" edge with a given conditions (other predicates).
func ReleasedYear ¶
ReleasedYear applies equality check predicate on the "released_year" field. It's identical to ReleasedYearEQ.
func ReleasedYearEQ ¶
ReleasedYearEQ applies the EQ predicate on the "released_year" field.
func ReleasedYearGT ¶
ReleasedYearGT applies the GT predicate on the "released_year" field.
func ReleasedYearGTE ¶
ReleasedYearGTE applies the GTE predicate on the "released_year" field.
func ReleasedYearIn ¶
ReleasedYearIn applies the In predicate on the "released_year" field.
func ReleasedYearLT ¶
ReleasedYearLT applies the LT predicate on the "released_year" field.
func ReleasedYearLTE ¶
ReleasedYearLTE applies the LTE predicate on the "released_year" field.
func ReleasedYearNEQ ¶
ReleasedYearNEQ applies the NEQ predicate on the "released_year" field.
func ReleasedYearNotIn ¶
ReleasedYearNotIn applies the NotIn predicate on the "released_year" field.
func Title ¶
Title applies equality check predicate on the "title" field. It's identical to TitleEQ.
func TitleContains ¶
TitleContains applies the Contains predicate on the "title" field.
func TitleContainsFold ¶
TitleContainsFold applies the ContainsFold predicate on the "title" field.
func TitleEqualFold ¶
TitleEqualFold applies the EqualFold predicate on the "title" field.
func TitleHasPrefix ¶
TitleHasPrefix applies the HasPrefix predicate on the "title" field.
func TitleHasSuffix ¶
TitleHasSuffix applies the HasSuffix predicate on the "title" field.
func TitleNotIn ¶
TitleNotIn applies the NotIn predicate on the "title" field.
func ValidColumn ¶
ValidColumn reports if the column name is valid (part of the table columns).
Types ¶
type OrderOption ¶
OrderOption defines the ordering options for the Song queries.
func ByArtistField ¶
func ByArtistField(field string, opts ...sql.OrderTermOption) OrderOption
ByArtistField orders the results by artist field.
func ByArtistID ¶
func ByArtistID(opts ...sql.OrderTermOption) OrderOption
ByArtistID orders the results by the artist_id field.
func ByID ¶
func ByID(opts ...sql.OrderTermOption) OrderOption
ByID orders the results by the id field.
func ByReleasedYear ¶
func ByReleasedYear(opts ...sql.OrderTermOption) OrderOption
ByReleasedYear orders the results by the released_year field.
func ByTitle ¶
func ByTitle(opts ...sql.OrderTermOption) OrderOption
ByTitle orders the results by the title field.